# pyPreservica
Python language binding for the Preservica API

This library provides a Python class for working with the Preservica Entity Rest API

https://us.preservica.com/api/entity/documentation.html


The full documentation is available at: https://pypreservica.readthedocs.io/
